@@ -21,7 +21,7 @@ import socket
 import httplib
 import urlparse
 import tempfile
-import threading
+import multiprocessing
 
 from StringIO import StringIO
 
@@ -37,6 +37,12 @@ try:
 except ImportError:
     StaticFilesHandler = None
 
+try:
+    import SocketServer
+    SocketServer.BaseServer.handle_error = lambda *args, **kw: None
+except ImportError:
+    pass
+
 from lettuce.registry import call_hook
 
 
@@ -46,22 +52,6 @@ class LettuceServerException(WSGIServerException):
 keep_running = True
 
 
-class StopabbleHandler(object):
-    """WSGI middleware that intercepts HTTP method DELETE at / and
-    kills through StopIteration exception server"""
-
-    def __init__(self, application):
-        self.application = application
-
-    def __call__(self, environ, start_response):
-        if environ['PATH_INFO'] == '/' and \
-               environ['REQUEST_METHOD'] == 'DELETE':
-            global keep_running
-            keep_running = False
-
-        return self.application(environ, start_response)
-
-
 class MutedRequestHandler(WSGIRequestHandler):
     """ A RequestHandler that silences output, in order to don't
     mess with Lettuce's output"""
@@ -88,6 +78,9 @@ class MutedRequestHandler(WSGIRequestHandler):
 
 
 class LettuceServerHandler(ServerHandler):
+    def handle_error(self, request, client_address):
+        pass
+
     def finish_response(self):
         try:
             ServerHandler.finish_response(self)
@@ -101,14 +94,14 @@ class LettuceServerHandler(ServerHandler):
                 raise
 
 
-class ThreadedServer(threading.Thread):
+class ThreadedServer(multiprocessing.Process):
     """
     Runs django's builtin in background
     """
-    lock = threading.Lock()
+    lock = multiprocessing.Lock()
 
     def __init__(self, address, port, *args, **kw):
-        threading.Thread.__init__(self)
+        multiprocessing.Process.__init__(self)
         self.address = address
         self.port = port
 
@@ -184,11 +177,10 @@ class ThreadedServer(threading.Thread):
                 "django's builtin server on it" % self.port,
             )
 
-        handler = StopabbleHandler(WSGIHandler())
+        handler = WSGIHandler()
         if 'django.contrib.admin' in settings.INSTALLED_APPS:
             admin_media_path = ''
             handler = AdminMediaHandler(handler, admin_media_path)
-            print "Preparing to serve django's admin site static files..."
 
         if self.should_serve_static_files():
             handler = StaticFilesHandler(handler)
@@ -200,8 +192,10 @@ class ThreadedServer(threading.Thread):
             call_hook('before', 'handle_request', httpd, self)
             httpd.handle_request()
             call_hook('after', 'handle_request', httpd, self)
-            if self.lock.locked():
+            try:
                 self.lock.release()
+            except ValueError:
+                pass
 
 
 class Server(object):
@@ -217,7 +211,9 @@ class Server(object):
     def start(self):
         """Starts the webserver thread, and waits it to be available"""
         call_hook('before', 'runserver', self._actual_server)
-        self._actual_server.setDaemon(True)
+        if 'django.contrib.admin' in settings.INSTALLED_APPS:
+            print "Preparing to serve django's admin site static files..."
+
         self._actual_server.start()
         self._actual_server.wait()
 
@@ -225,17 +221,13 @@ class Server(object):
         print "Django's builtin server is running at %s:%d" % addrport
 
     def stop(self, fail=False):
-        http = httplib.HTTPConnection(self.address, self.port)
-        try:
-            http.request("DELETE", "/")
-            http.getresponse().read()
-        except socket.error:
-            pass
-        finally:
-            http.close()
-            code = int(fail)
-            call_hook('after', 'runserver', self._actual_server)
-            return sys.exit(code)
+        pid = self._actual_server.pid
+        if pid:
+            os.kill(pid, 9)
+
+        code = int(fail)
+        call_hook('after', 'runserver', self._actual_server)
+        return sys.exit(code)
 
     def url(self, url=""):
         base_url = "http://%s" % ThreadedServer.get_real_address(self.address)
